# -*- coding: utf-8 -*-

from pythonperlin.perlin import perlin, extend2d
from pkg_resources import get_distribution

__version__ = get_distribution('pythonperlin').version